import axios from 'axios'

const BASE_URL = 'https://cinema.kolei.ru'

const api = axios.create({
  baseURL: BASE_URL,
  headers: {
    'Content-Type': 'application/json'
  }
})


api.interceptors.request.use(config => {
  const token = localStorage.getItem('token')
  if (token) {
    config.headers.Authorization = `Bearer ${token}`
  }
  return config
})

export async function getMovies(){
  const response = await fetch(`${BASE_URL}/movies?filter=new`)
  console.log(response)
  return response.json()
}


export const authAPI = {
  login: async (email, password) => {
    try {
      const response = await api.post('/auth/login', {
        email,
        password
      })

      if (response.data.token) {
        localStorage.setItem('token', response.data.token)
        localStorage.setItem('userData', JSON.stringify({
          firstName: response.data.firstName,
          lastName: response.data.lastName,
          email: response.data.email
        }))
      }
      return response.data
    } catch (error) {
      console.log(error)
    }
  },

  register: async (userData) => {
    try {
      const response = await api.post('/auth/register', {
        firstName: userData.firstName,
        lastName: userData.lastName,
        email: userData.email,
        password: userData.password
      })
      return response.data
    } catch (error) {
      console.log(error)
    }
  },

  getFilePath: (fileName) => {
    return `${BASE_URL}/up/images/${fileName}`
  },

  getUserData: async () => {
    try {
      const response = await api.get('/user');
      return response.data
    } catch (error) {
      console.error('Ошибка при получении данных пользователя:', error)
    }
  },

  getUserAvatar: async () => {
    try {
      const response = await api.get('/user')
      if (response.data && Array.isArray(response.data) && response.data[0].avatar) {
        return `${BASE_URL}/up/images/${response.data[0].avatar}`
      }
      return null
    } catch (error) {
      console.error('Error getting user avatar:', error)
      return null
    }
  },

  uploadFile: async (file) => {
    const formData = new FormData()
    formData.append('file', file)

    try {
      const response = await api.post('/file/uploadImage', formData, {
        headers: {
          'Content-Type': 'multipart/form-data',
          'Authorization': `Bearer ${localStorage.getItem('token')}`
        }
      })
      return response.data
    } catch (error) {
      console.error('Error uploading file:', error)
      throw error
    }
  },

  logout: () => {
    localStorage.removeItem('token')
  }
}

export default api
