import { createStore } from 'vuex'
import createPersistedState from 'vuex-persistedstate'

export default createStore({
  state: {
    users: [],
    currentUser: null,
    collections: [
      { id: 1, name: 'Избранное', icon: '/icons/Group 1.png' },
      { id: 2, name: 'Когда-нибудь', icon: '/icons/Group 2.png' },
      { id: 3, name: 'В поездку', icon: '/icons/Group 3.png' }
    ]
  },
  mutations: {
    addUser(state, user) {
      state.users.push(user)
    },
    setCurrentUser(state, user) {
      state.currentUser = user
    },
    logout(state) {
      state.currentUser = null
    },
    addCollection(state, collection) {
      if (!state.collections.some(c => c.id === collection.id)) {
        state.collections.push(collection)
      }
    },
    initializeCollections(state) {
      const defaultCollections = [
        { id: 1, name: 'Избранное', icon: '/icons/Group 1.png' },
        { id: 2, name: 'Когда-нибудь', icon: '/icons/Group 2.png' },
        { id: 3, name: 'В поездку', icon: '/icons/Group 3.png' }
      ]

      if (state.collections.length === 0) {
        state.collections = defaultCollections
      }
    }
  },
  actions: {
    registerUser({ commit }, user) {
      commit('addUser', user)
    },
    loginUser({ commit, state }, credentials) {
      const user = state.users.find(
        u => u.email === credentials.email && u.password === credentials.password
      )
      if (user) {
        commit('setCurrentUser', user)
        return true
      }
      return false
    },
    logoutUser({ commit }) {
      commit('logout')
    },
    saveCollection({ commit }, collection) {
      commit('addCollection', {
        id: Date.now(),
        ...collection
      })
    },
    initializeStore({ commit }) {
      commit('initializeCollections')
    }
  },
  getters: {
    isAuthenticated: state => !!state.currentUser,
    currentUser: state => state.currentUser,
    getUserCollections: state => state.collections
  },
  plugins: [createPersistedState()]
})
